# tree-sitter-rune

[![Build/test](https://github.com/zhuhaow/tree-sitter-rune/actions/workflows/ci.yml/badge.svg)](https://github.com/zhuhaow/tree-sitter-rune/actions/workflows/ci.yml)

[Tree-sitter](https://tree-sitter.github.io/tree-sitter/) grammar for the [Rune programming language](https://rune-rs.github.io).

## About Rune

Rune is a language for programmatic scripting and configuration. It's designed to be embedded in Rust applications as a dynamic scripting layer.

Learn more about the Rune language at its [official website](https://rune-rs.github.io) and [documentation](https://rune-rs.github.io/book/).

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## License

This project is licensed under the MIT License - see the LICENSE file for details.
